extends Node2D

func _ready() -> void:
	print(OS.get_cmdline_args())
	for arg in OS.get_cmdline_args():
		printt("single arg:", arg)

	print("---")
	var fixed_args := fix_godot_cmdline_args_string_space_splitting(OS.get_cmdline_args())
	print(fixed_args)
	for arg in fixed_args:
		printt("fixed arg:", arg)


# Reverses a bug in Godot, which splits input strings at spaces even if they are quoted
# e.g. --arg="some value" becomes [ --arg="some, value" ]
# this only occurs with args in that format. --arg "some value" is safe
static func fix_godot_cmdline_args_string_space_splitting(args: PoolStringArray) -> PoolStringArray:
	if not OS.has_feature("editor"): # only happens in editor builds
		return args
	if OS.has_feature("Windows"): # windows is unaffected
		return args

	var fixed_args := PoolStringArray([])
	var fixed_arg := ""
	# if we encounter an argument that contains [code]=[/code] followed by a quote,
	# or an argument that starts with a quote, take all following args and
	# concatenate them into one, until we find the closing quote
	for arg in args:
		var arg_string := arg as String
		if '="' in arg_string or '="' in fixed_arg or \
				arg_string.begins_with('"') or fixed_arg.begins_with('"'):
			if not fixed_arg == "":
				fixed_arg += " "
			fixed_arg += arg_string
			if arg_string.ends_with('"'):
				fixed_args.append(fixed_arg.trim_prefix(" "))
				fixed_arg = ""
				continue
		# same thing for single quotes
		elif "='" in arg_string or "='" in fixed_arg \
				or arg_string.begins_with("'") or fixed_arg.begins_with("'"):
			if not fixed_arg == "":
				fixed_arg += " "
			fixed_arg += arg_string
			if arg_string.ends_with("'"):
				fixed_args.append(fixed_arg.trim_prefix(" "))
				fixed_arg = ""
				continue

		else:
			fixed_args.append(arg_string)

	return fixed_args
